<?php

namespace Drupal\broadstreet_ads\Plugin\Derivative;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Derivative for ad blocks.
 */
class AdBlock extends DeriverBase implements ContainerDeriverInterface {

  /**
   * The broadstreet_ads.settings config object.
   *
   * @var \Drupal\Core\Config\Config
   */
  protected $config;

  /**
   * Constructs a new AdBlock object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory service.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->config = $config_factory->get('broadstreet_ads.settings');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('config.factory'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    $zones = $this->config->get('zones');
    if (!empty($zones)) {
      foreach (explode("\n", $zones) as $zone) {
        if (!empty($zone)) {
          if (strpos($zone, '|')) {
            [$zone_id, $zone_label] = explode('|', $zone);
            $zone_id = intval(trim($zone_id));
            $zone_label = trim($zone_label);
          }
          else {
            $zone_id = intval($zone);
            $zone_label = 'Zone #' . $zone_id;
          }
          $this->derivatives[$zone_id] = $base_plugin_definition;
          $this->derivatives[$zone_id]['admin_label'] = 'Broadstreet Ads: ' . $zone_label;
        }
      }
    }

    return $this->derivatives;
  }

}
